aboutsummaryrefslogtreecommitdiff
path: root/include
diff options
context:
space:
mode:
Diffstat (limited to 'include')
-rw-r--r--include/curl/curl.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/include/curl/curl.h b/include/curl/curl.h
index de709655d..3f5c49a27 100644
--- a/include/curl/curl.h
+++ b/include/curl/curl.h
@@ -1309,11 +1309,11 @@ typedef enum {
/* Manually initialize the server RTSP CSeq for this handle */
CINIT(RTSP_SERVER_CSEQ, LONG, 194),
- /* The stream to pass to RTPFUNCTION. */
- CINIT(RTPDATA, OBJECTPOINT, 195),
+ /* The stream to pass to INTERLEAVEFUNCTION. */
+ CINIT(INTERLEAVEDATA, OBJECTPOINT, 195),
/* Let the application define a custom write method for RTP data */
- CINIT(RTPFUNCTION, FUNCTIONPOINT, 196),
+ CINIT(INTERLEAVEFUNCTION, FUNCTIONPOINT, 196),
CURLOPT_LASTENTRY /* the last unused */
} CURLoption;